@@ -431,6 +431,15 @@ class CloudPickleTest(unittest.TestCase):
         self.assertEqual(A.test_sm(), "sm")
         self.assertEqual(A.test_cm(), "cm")
 
+    def test_bound_classmethod(self):
+        class A:
+            @classmethod
+            def test_cm(cls):
+                return "cm"
+
+        A.test_cm = pickle_depickle(A.test_cm, protocol=self.protocol)
+        self.assertEqual(A.test_cm(), "cm")
+
     def test_method_descriptors(self):
         f = pickle_depickle(str.upper)
         self.assertEqual(f('abc'), 'ABC')
@@ -661,10 +670,9 @@ class CloudPickleTest(unittest.TestCase):
         # builtin function from the __builtin__ module
         assert pickle_depickle(zip, protocol=self.protocol) is zip
 
-        from sys import getcheckinterval
+        from os import mkdir
         # builtin function from a "regular" module
-        assert pickle_depickle(
-            getcheckinterval, protocol=self.protocol) is getcheckinterval
+        assert pickle_depickle(mkdir, protocol=self.protocol) is mkdir
 
     @pytest.mark.skipif(platform.python_implementation() == 'PyPy' and
                         sys.version_info[:2] == (3, 5),
@@ -975,6 +983,11 @@ class CloudPickleTest(unittest.TestCase):
         # logging.Logger object
         self.check_logger('cloudpickle.dummy_test_logger')
 
+    def test_getset_descriptor(self):
+        assert isinstance(float.real, types.GetSetDescriptorType)
+        depickled_descriptor = pickle_depickle(float.real)
+        self.assertIs(depickled_descriptor, float.real)
+
     def test_abc(self):
 
         @abc.abstractmethod
@@ -1607,9 +1620,9 @@ class CloudPickleTest(unittest.TestCase):
 
         self.assertEqual(f2.__doc__, f.__doc__)
 
-    @unittest.skipIf(sys.version_info < (3, 4),
-                     """This syntax won't work on py2 and pickling annotations
-                     isn't supported for py34 and below.""")
+    @unittest.skipIf(sys.version_info < (3, 7),
+                     "This syntax won't work on py2 and pickling annotations "
+                     "isn't supported for py37 and below.")
     def test_wraps_preserves_function_annotations(self):
         from functools import wraps
 
@@ -1626,6 +1639,16 @@ class CloudPickleTest(unittest.TestCase):
 
         self.assertEqual(f2.__annotations__, f.__annotations__)
 
+    @unittest.skipIf(sys.version_info < (3, 7),
+                     """This syntax won't work on py2 and pickling annotations
+                     isn't supported for py37 and below.""")
+    def test_type_hint(self):
+        # Try to pickle compound typing constructs. This would typically fail
+        # on Python < 3.7 (See #193)
+        import typing
+        t = typing.Union[list, int]
+        assert pickle_depickle(t) == t
+
     def test_instance_with_slots(self):
         for slots in [["registered_attribute"], "registered_attribute"]:
             class ClassWithSlots(object):
